package com.landray.kmss.sys.attachment.restservice.wps.controller;

import org.springframework.util.MultiValueMap;
import org.springframework.http.HttpStatus;
import java.io.ByteArrayOutputStream;
import org.springframework.http.MediaType;
import org.springframework.http.HttpHeaders;
import org.springframework.http.ResponseEntity;
import com.landray.kmss.common.model.IBaseModel;
import org.springframework.web.multipart.MultipartFile;
import net.sf.json.JSONArray;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RequestMethod;
import com.landray.kmss.sys.attachment.util.SysAttViewerUtil;
import java.util.Date;
import net.sf.json.JSONObject;
import com.landray.kmss.sys.organization.model.SysOrgPerson;
import com.landray.kmss.util.SpringBeanUtil;
import com.landray.kmss.sys.organization.service.ISysOrgPersonService;
import org.springframework.web.bind.annotation.RequestParam;
import javax.servlet.http.HttpServletResponse;
import de.sty.io.mimetype.helper.RuntimeException;
import com.landray.kmss.util.StringUtil;
import javax.servlet.http.HttpServletRequest;
import java.io.InputStream;
import java.util.List;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.io.IOUtils;
import java.io.FileInputStream;
import java.io.File;
import com.landray.kmss.sys.config.loader.ConfigLocationsUtil;
import com.landray.kmss.sys.person.interfaces.PersonInfoServiceGetter;
import com.landray.kmss.sys.attachment.model.SysAttMain;
import com.landray.kmss.sys.attachment.util.ImageCropUtil;
import com.landray.kmss.sys.zone.model.SysZonePersonInfo;
import org.slf4j.LoggerFactory;
import com.landray.kmss.sys.filestore.service.ISysAttUploadService;
import com.landray.kmss.sys.attachment.service.ISysAttMainCoreInnerService;
import org.slf4j.Logger;
import com.landray.kmss.web.annotation.RestApi;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.stereotype.Controller;

@Controller
@RequestMapping({ "/api/sys-attachment/sysAttachmentWpsRestService" })
@RestApi(docUrl = "/sys/attachment/restservice/sysAttachmentRestServiceHelp.jsp", name = "sysAttachmentWpsRestService", resourceKey = "sys-attachment:sysAttachmentWpsRestService.title")
public class SysAttachmentWpsController
{
    private static final Logger logger;
    private ISysAttMainCoreInnerService sysAttMainService;
    private ISysAttUploadService sysAttUploadService;
    
    static {
        logger = LoggerFactory.getLogger(SysAttachmentWpsController.class);
    }
    
    public void setSysAttMainService(final ISysAttMainCoreInnerService sysAttMainService) {
        this.sysAttMainService = sysAttMainService;
    }
    
    public void setSysAttUploadService(final ISysAttUploadService sysAttUploadService) {
        this.sysAttUploadService = sysAttUploadService;
    }
    
    private String getPersonImage(final String personId) throws Exception {
        String personImageUrl = "";
        final String modelName = SysZonePersonInfo.class.getName();
        final String fdKey = "personPic" + ImageCropUtil.CROP_KEYS[0];
        List list = this.sysAttMainService.findByModelKey(modelName, personId, fdKey);
        if (list.isEmpty()) {
            list = this.sysAttMainService.findByModelKey(modelName, personId, "zonePersonInfo");
        }
        if (list != null && !list.isEmpty()) {
            final SysAttMain sysAtt = list.get(0);
            personImageUrl = this.sysAttMainService.getRestDownloadUrl(sysAtt.getFdId());
        }
        else {
            final String defaultHeadImageUrl = PersonInfoServiceGetter.getPersonDefaultHeadImageUrl(personId);
            final File file = new File(String.valueOf(ConfigLocationsUtil.getWebContentPath()) + defaultHeadImageUrl);
            if (file.exists()) {
                final InputStream in = new FileInputStream(file);
                final byte[] bytes = IOUtils.toByteArray(in);
                personImageUrl = "data:image/png;base64," + new String(Base64.encodeBase64(bytes));
            }
        }
        return personImageUrl;
    }
    
    private boolean checkToken(final HttpServletRequest request) throws Exception {
        boolean result = true;
        final String token = request.getHeader("x-wps-weboffice-token");
        final String fileId = request.getHeader("x-weboffice-file-id");
        final String expires = request.getParameter("_w_Expires");
        System.out.println();
        System.out.println("token:" + token);
        System.out.println("fileId:" + fileId);
        System.out.println("expires:" + expires);
        if (StringUtil.isNotNull(expires) && Long.valueOf(expires) < System.currentTimeMillis()) {
            throw new RuntimeException("token已过期");
        }
        result = this.sysAttMainService.validateDownloadSignatureRest(expires, fileId, token);
        if (!result) {
            throw new RuntimeException("请求签名无效");
        }
        return result;
    }
    
    @RequestMapping(value = { "/v1/3rd/file/info" }, method = { RequestMethod.GET })
    @ResponseBody
    public Object fileInfo(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("_w_fileId") final String fileId) throws Exception {
        System.out.println("/v1/3rd/file/info被调用");
        if (fileId == null || fileId.isEmpty()) {
            return null;
        }
        final SysAttMain sysAttMain = (SysAttMain)this.sysAttMainService.findByPrimaryKey(fileId);
        if (sysAttMain == null) {
            return null;
        }
        if (this.checkToken(request)) {
            final String fdMode = request.getParameter("_w_fdMode");
            final String userid = request.getParameter("_w_userid");
            final String username = request.getParameter("_w_username");
            String markword = request.getParameter("_w_markWord");
            final ISysOrgPersonService sysOrgPersonService = (ISysOrgPersonService)SpringBeanUtil.getBean("sysOrgPersonService");
            final SysOrgPerson creator = (SysOrgPerson)sysOrgPersonService.findByPrimaryKey(sysAttMain.getFdCreatorId());
            final String filename = sysAttMain.getFdFileName();
            final JSONObject jsonObject = new JSONObject();
            final JSONObject file = new JSONObject();
            final JSONObject user = new JSONObject();
            try {
                file.put((Object)"id", (Object)fileId);
                file.put((Object)"name", (Object)filename);
                file.put((Object)"version", (Object)1);
                file.put((Object)"size", (Object)sysAttMain.getFdSize());
                file.put((Object)"creator", (Object)creator.getFdName());
                file.put((Object)"create_time", (Object)((sysAttMain.getDocCreateTime() != null) ? sysAttMain.getDocCreateTime().getTime() : new Date().getTime()));
                file.put((Object)"modifier", (Object)username);
                file.put((Object)"modify_time", (Object)new Date().getTime());
                file.put((Object)"download_url", (Object)this.sysAttMainService.getRestDownloadUrl(fileId));
                final JSONObject watermarkCfg = SysAttViewerUtil.getWaterMarkConfigInDB(Boolean.valueOf(true));
                if (StringUtil.isNull(markword)) {
                    markword = username;
                }
                final JSONObject watermark = new JSONObject();
                watermark.put((Object)"type", (Object)1);
                watermark.put((Object)"value", (Object)markword);
                String markOpacity = "rgba( 192, 192, 192, 0.6 )";
                if (watermarkCfg.get("markOpacity") != null) {
                    markOpacity = "rgba( 192, 192, 192, " + watermarkCfg.get("markOpacity") + ")";
                }
                watermark.put((Object)"fillstyle", (Object)markOpacity);
                String markWordFontFamily = "bold 20px Serif";
                if (watermarkCfg.get("markWordFontFamily") != null) {
                    markWordFontFamily = "bold " + watermarkCfg.get("markWordFontSize") + "px " + watermarkCfg.get("markWordFontFamily");
                }
                watermark.put((Object)"font", (Object)markWordFontFamily);
                watermark.put((Object)"rotate", (Object)(-0.7853982));
                int markRowSpace = 50;
                if (watermarkCfg.get("markRowSpace") != null) {
                    markRowSpace = watermarkCfg.getInt("markRowSpace");
                }
                watermark.put((Object)"horizontal", (Object)markRowSpace);
                int markColSpace = 100;
                if (watermarkCfg.get("markColSpace") != null) {
                    markColSpace = watermarkCfg.getInt("markColSpace");
                }
                watermark.put((Object)"vertical", (Object)markColSpace);
                file.put((Object)"watermark", (Object)watermark);
                jsonObject.put((Object)"file", (Object)file);
                user.put((Object)"id", (Object)userid);
                user.put((Object)"name", (Object)username);
                user.put((Object)"permission", (Object)fdMode);
                user.put((Object)"avatar_url", (Object)this.getPersonImage(userid));
                jsonObject.put((Object)"user", (Object)user);
            }
            catch (final Exception e) {
                e.printStackTrace();
            }
            return jsonObject.toString();
        }
        return null;
    }
    
    @RequestMapping(value = { "/v1/3rd/user/info" }, method = { RequestMethod.POST })
    @ResponseBody
    public Object userInfo(final HttpServletRequest request, final HttpServletResponse response, @RequestBody final String ids) throws Exception {
        System.out.println("/v1/3rd/user/info被调用");
        if (this.checkToken(request)) {
            final ISysOrgPersonService sysOrgPersonService = (ISysOrgPersonService)SpringBeanUtil.getBean("sysOrgPersonService");
            if (StringUtil.isNotNull(ids)) {
                final JSONObject paramJson = JSONObject.fromObject((Object)ids);
                if (paramJson.get("ids") != null) {
                    final JSONArray idArray = paramJson.getJSONArray("ids");
                    if (!idArray.isEmpty()) {
                        final JSONObject jsonObject = new JSONObject();
                        final JSONArray jsonArray = new JSONArray();
                        for (int i = 0; i < idArray.size(); ++i) {
                            final String id = idArray.getString(i);
                            final SysOrgPerson person = (SysOrgPerson)sysOrgPersonService.findByPrimaryKey(id, (Object)SysOrgPerson.class, true);
                            if (person != null) {
                                final JSONObject user = new JSONObject();
                                user.put((Object)"id", (Object)person.getFdId());
                                user.put((Object)"name", (Object)person.getFdName());
                                user.put((Object)"avatar_url", (Object)this.getPersonImage(person.getFdId()));
                                jsonArray.add((Object)user);
                            }
                        }
                        jsonObject.put((Object)"users", (Object)jsonArray);
                        return jsonObject.toString();
                    }
                }
            }
        }
        return null;
    }
    
    @RequestMapping(value = { "/v1/3rd/file/online" }, method = { RequestMethod.POST })
    @ResponseBody
    public void online(final HttpServletRequest request, final HttpServletResponse response, @RequestBody final String ids) throws Exception {
        System.out.println("/v1/3rd/file/online被调用");
        if (this.checkToken(request) && StringUtil.isNotNull(ids)) {
            final JSONObject paramJson = JSONObject.fromObject((Object)ids);
            if (paramJson.get("ids") != null) {
                final JSONArray idArray = paramJson.getJSONArray("ids");
                if (!idArray.isEmpty()) {
                    for (int i = 0; i < idArray.size(); ++i) {
                        System.out.println("id:" + idArray.getString(i));
                    }
                }
            }
        }
    }
    
    @RequestMapping(value = { "/v1/3rd/file/save" }, method = { RequestMethod.POST })
    @ResponseBody
    public Object save(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("file") final MultipartFile file, @RequestParam("_w_fileId") final String fileId) throws Exception {
        System.out.println("/v1/3rd/file/save被调用");
        if (this.checkToken(request)) {
            final JSONObject jsonObject = new JSONObject();
            final JSONObject fileInfo = new JSONObject();
            if (!file.isEmpty() && StringUtil.isNotNull(fileId)) {
                try {
                    final SysAttMain sysAttMain = (SysAttMain)this.sysAttMainService.findByPrimaryKey(fileId);
                    if (sysAttMain != null) {
                        final InputStream in = file.getInputStream();
                        sysAttMain.setInputStream(in);
                        sysAttMain.setFdSize(new Double(in.available()));
                        this.sysAttMainService.update((IBaseModel)sysAttMain);
                        fileInfo.put((Object)"id", (Object)fileId);
                        fileInfo.put((Object)"name", (Object)sysAttMain.getFdFileName());
                        fileInfo.put((Object)"version", (Object)1);
                        fileInfo.put((Object)"size", (Object)sysAttMain.getFdSize());
                        fileInfo.put((Object)"download_url", (Object)this.sysAttMainService.getRestDownloadUrl(fileId));
                        jsonObject.put((Object)"file", (Object)fileInfo);
                    }
                }
                catch (final Exception e) {
                    e.printStackTrace();
                }
            }
            return jsonObject.toString();
        }
        return null;
    }
    
    @RequestMapping(value = { "/v1/3rd/file/version" }, method = { RequestMethod.GET })
    @ResponseBody
    public Object fileVersionInfo(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("_w_fileId") final String fileId) throws Exception {
        System.out.println("/v1/3rd/file/version被调用");
        if (fileId == null || fileId.isEmpty()) {
            return null;
        }
        final SysAttMain sysAttMain = (SysAttMain)this.sysAttMainService.findByPrimaryKey(fileId);
        if (sysAttMain == null) {
            return null;
        }
        if (this.checkToken(request)) {
            final ISysOrgPersonService sysOrgPersonService = (ISysOrgPersonService)SpringBeanUtil.getBean("sysOrgPersonService");
            final SysOrgPerson creator = (SysOrgPerson)sysOrgPersonService.findByPrimaryKey(sysAttMain.getFdCreatorId());
            final String filename = sysAttMain.getFdFileName();
            final JSONObject jsonObject = new JSONObject();
            final JSONObject file = new JSONObject();
            final String username = request.getParameter("_w_username");
            try {
                file.put((Object)"id", (Object)fileId);
                file.put((Object)"name", (Object)filename);
                file.put((Object)"version", (Object)1);
                file.put((Object)"size", (Object)sysAttMain.getFdSize());
                file.put((Object)"creator", (Object)creator.getFdName());
                file.put((Object)"create_time", (Object)sysAttMain.getDocCreateTime().getTime());
                file.put((Object)"modifier", (Object)username);
                file.put((Object)"modify_time", (Object)new Date().getTime());
                file.put((Object)"download_url", (Object)this.sysAttMainService.getRestDownloadUrl(fileId));
                jsonObject.put((Object)"file", (Object)file);
            }
            catch (final Exception e) {
                e.printStackTrace();
            }
            return jsonObject.toString();
        }
        return null;
    }
    
    @RequestMapping(value = { "/v1/3rd/file/rename" }, method = { RequestMethod.PUT })
    @ResponseBody
    public Object fileRename(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("_w_fileId") final String fileId) throws Exception {
        System.out.println("/v1/3rd/file/rename被调用");
        if (this.checkToken(request)) {
            final String fdNewName = request.getParameter("name");
            int status = 200;
            String msg = "重命名成功";
            try {
                if (fileId == null || fileId.isEmpty()) {
                    msg = "文件不存在";
                    return null;
                }
                final SysAttMain sysAttMain = (SysAttMain)this.sysAttMainService.findByPrimaryKey(fileId);
                if (sysAttMain == null) {
                    msg = "文件不存在";
                    return null;
                }
                sysAttMain.setFdFileName(fdNewName);
                this.sysAttMainService.update((IBaseModel)sysAttMain);
            }
            catch (final Exception e) {
                status = response.getStatus();
                msg = e.getMessage();
            }
            final JSONObject result = new JSONObject();
            result.put((Object)"status", (Object)status);
            result.put((Object)"msg", (Object)msg);
            return result.toString();
        }
        return null;
    }
    
    @RequestMapping(value = { "/v1/3rd/file/history" }, method = { RequestMethod.POST })
    @ResponseBody
    public Object fileHstoryInfo(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("_w_fileId") final String fileId) throws Exception {
        System.out.println("/v1/3rd/file/history被调用");
        if (fileId == null || fileId.isEmpty()) {
            return null;
        }
        final SysAttMain sysAttMain = (SysAttMain)this.sysAttMainService.findByPrimaryKey(fileId);
        if (sysAttMain == null) {
            return null;
        }
        if (this.checkToken(request)) {
            final ISysOrgPersonService sysOrgPersonService = (ISysOrgPersonService)SpringBeanUtil.getBean("sysOrgPersonService");
            final SysOrgPerson creator = (SysOrgPerson)sysOrgPersonService.findByPrimaryKey(sysAttMain.getFdCreatorId());
            final String filename = sysAttMain.getFdFileName();
            final JSONObject jsonObject = new JSONObject();
            final JSONArray fileArr = new JSONArray();
            final JSONObject file = new JSONObject();
            final JSONObject creatorObj = new JSONObject();
            final JSONObject modifierObj = new JSONObject();
            final String userid = request.getParameter("_w_userid");
            final String username = request.getParameter("_w_username");
            try {
                file.put((Object)"id", (Object)fileId);
                file.put((Object)"name", (Object)filename);
                file.put((Object)"version", (Object)1);
                file.put((Object)"size", (Object)sysAttMain.getFdSize());
                file.put((Object)"create_time", (Object)sysAttMain.getDocCreateTime().getTime());
                file.put((Object)"modify_time", (Object)new Date().getTime());
                file.put((Object)"download_url", (Object)this.sysAttMainService.getRestDownloadUrl(fileId));
                creatorObj.put((Object)"id", (Object)creator.getFdId());
                creatorObj.put((Object)"name", (Object)creator.getFdName());
                creatorObj.put((Object)"avatar_url", (Object)this.getPersonImage(creator.getFdId()));
                file.put((Object)"creator", (Object)creatorObj);
                modifierObj.put((Object)"id", (Object)userid);
                modifierObj.put((Object)"name", (Object)username);
                modifierObj.put((Object)"avatar_url", (Object)this.getPersonImage(userid));
                file.put((Object)"modifier", (Object)modifierObj);
                fileArr.add((Object)file);
                jsonObject.put((Object)"histories", (Object)fileArr);
            }
            catch (final Exception e) {
                e.printStackTrace();
            }
            return jsonObject.toString();
        }
        return null;
    }
    
    @RequestMapping(value = { "/v1/3rd/file/new" }, method = { RequestMethod.POST })
    @ResponseBody
    public Object newFile(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("file") final MultipartFile file, @RequestParam("name") final String filename) throws Exception {
        final JSONObject jsonObject = new JSONObject();
        System.out.println("/v1/3rd/file/new被调用");
        if (this.checkToken(request)) {
            if (!file.isEmpty() && StringUtil.isNotNull(filename)) {
                try {
                    final String fdKey = request.getParameter("_w_fdKey");
                    final String fdModelId = request.getParameter("_w_fdModelId");
                    final String fdModelName = request.getParameter("_w_fdModelName");
                    final SysAttMain sysAttMain = new SysAttMain();
                    sysAttMain.setFdKey(fdKey);
                    sysAttMain.setFdModelId(fdModelId);
                    sysAttMain.setFdModelName(fdModelName);
                    sysAttMain.setFdFileName(filename);
                    final InputStream in = file.getInputStream();
                    sysAttMain.setInputStream(in);
                    sysAttMain.setFdSize(new Double(in.available()));
                    this.sysAttMainService.add((IBaseModel)sysAttMain);
                    jsonObject.put((Object)"redirect_url", (Object)this.sysAttMainService.getRestDownloadUrl(sysAttMain.getFdId()));
                    jsonObject.put((Object)"user_id", (Object)sysAttMain.getFdCreatorId());
                }
                catch (final Exception e) {
                    e.printStackTrace();
                }
            }
            return jsonObject.toString();
        }
        return null;
    }
    
    @RequestMapping(value = { "/v1/3rd/onnotify" }, method = { RequestMethod.POST })
    @ResponseBody
    public Object notifyMsg(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        System.out.println("/v1/3rd/onnotify被调用");
        if (this.checkToken(request)) {
            final JSONObject jsonObject = new JSONObject();
            final String cmd = request.getParameter("cmd");
            final String body = request.getParameter("body");
            System.out.println(cmd);
            System.out.println(body);
            jsonObject.put((Object)"msg", (Object)"success");
            return jsonObject;
        }
        return null;
    }
    
    @ResponseBody
    @RequestMapping(value = { "/download" }, method = { RequestMethod.GET })
    public ResponseEntity<byte[]> downloadFile(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("fdId") final String fdId, @RequestParam("Expires") final String Expires, @RequestParam("token") final String token) throws Exception {
        if (this.sysAttMainService.validateDownloadSignatureRest(Expires, fdId, token)) {
            byte[] byt = null;
            final HttpHeaders headers = new HttpHeaders();
            try {
                final ISysAttMainCoreInnerService sysAttMainService = (ISysAttMainCoreInnerService)SpringBeanUtil.getBean("sysAttMainService");
                final SysAttMain sysAttMain = (SysAttMain)sysAttMainService.findByPrimaryKey(fdId);
                final InputStream in = sysAttMainService.getInputStream(sysAttMain);
                final String filename = sysAttMain.getFdFileName();
                headers.setContentDispositionFormData("attachment", new String(filename.getBytes("UTF-8"), "ISO8859-1"));
                headers.setPragma("public");
                headers.setContentType(MediaType.APPLICATION_OCTET_STREAM);
                final ByteArrayOutputStream bao = new ByteArrayOutputStream();
                final byte[] buff = new byte[100];
                int rc = 0;
                while ((rc = in.read(buff, 0, 100)) > 0) {
                    bao.write(buff, 0, rc);
                }
                byt = bao.toByteArray();
            }
            catch (final Exception e) {
                e.printStackTrace();
            }
            return (ResponseEntity<byte[]>)new ResponseEntity((Object)byt, (MultiValueMap)headers, HttpStatus.OK);
        }
        return null;
    }
}
